function y=mfilt2(im,k)
%MFILT performs median filtering of an image.
%	Y=MFILT2(IM,K)
% INPUT
%   IM - Input image
%   K -  KxK filter window. This parameter must be odd.
% OUTPUT
%   Y -  Output image

%   Rev 1.0     Apr. 15, 2002   Dmitiry Shutin <dshutin@inw.tugraz.at>
%   Rev 1.1     Oct. 06, 2002   Input variables test, paddarray bug corrected
%   Rev 2.0     Oct. 19, 2009   Daniel Arnitz <daniel.arnitz@tugraz.at>
%                               removed padarray (needs a toolbox)
%   Rev 2.1     Oct. 30, 2009   added typecast to class of input image

if nargin<1
   y=0;
   return;
end
if nargin<2
   k=1;
end
if ( k/2==floor(k/2) )
   warning('Filter length parameter must be odd. K is increased by 1'); %#ok<WNTAG>
   k=k+1;
end
[N,M]=size(im);
l=(k-1)/2;
p_im = feval(class(im), zeros(size(im) + 2*l));
p_im(1+l:end-l, 1+l:end-l) = im;
for i=1+l:N+l
   for j=1+l:M+l
      tmp=p_im(i-l:i+l,j-l:j+l);
      y(i-l,j-l)=median(tmp(:));
   end
end




